% Ju and Zhon approximation for American options.  
% From "An Approximate Formula for Pricing American Options"
% Reproduces Exhibits 3,4,5 and 6.

clc; clear;

% Reproduce the last column of Exhibit 3
S = 40;
r = 0.0488;
q = 0;
K = [35:5:45];
V = [0.2 0.3 0.4];
T = [1/12 4/12 7/12];
phi = -1;
Price = [];
Labels = [];

for v=1:length(V);
	for k = 1:length(K);
		for t = 1:length(T);
			Price =  [Price; JuZhong(S,K(k),r,q,V(v),T(t),phi)];
			Labels = [Labels; K(k) V(v) T(t)];
		end
	end
end
Exhibit3 = [Labels Price]

% Reproduce the last column of Exhibit 4
K = 100;
T = 0.5;
phi = 1;
S = repmat([80:10:120],1,4);
V = [repmat(.2,1,5)   repmat(.4,1,5) repmat(.3,1,10)];
R = [repmat(.03,1,10) repmat(0,1,5)  repmat(.07,1,5)];
Q = [repmat(.07,1,15) repmat(.03,1,5)];

for i=1:20
	Exhibit4(i,:) = [S(i) V(i) R(i) Q(i) JuZhong(S(i),K,R(i),Q(i),V(i),T,phi)];
end
Exhibit4


% Reproduce the last column of Exhibit 5
K = 100;
T = 3;
v = 0.2;
r = 0.08;
S = [80:10:120];
Q = [.12 .08 .04 0];
phi = -1;
Price = [];
Labels = [];

for q=1:length(Q);
	for s = 1:length(S);
		Price =  [Price; JuZhong(S(s),K,r,Q(q),v,T,phi)];
		Labels = [Labels; S(s) Q(q)];
	end
end
Exhibit5 = [Labels Price]


% Reproduce the last column of Exhibit 6
K = 100;
T = 3;
phi = 1;

S = repmat([80:10:120],1,4);
V = [repmat(.2,1,5)   repmat(.4,1,5) repmat(.3,1,10)];
R = [repmat(.03,1,10) repmat(0,1,5)  repmat(.07,1,5)];
Q = [repmat(.07,1,15) repmat(.03,1,5)];

for i=1:20
	Exhibit6(i,:) = [S(i) V(i) Q(i) Q(i) JuZhong(S(i),K,R(i),Q(i),V(i),T,phi)];
end
Exhibit6

